@@ -4,7 +4,7 @@
  * Start Date:  Wed Dec 27 08:44:20 1995
  * Project:     INN (innfeed)
  * File:        host.h
- * RCSId:       $Id: host.h,v 1.9 1996/05/19 22:19:55 brister Exp brister $
+ * RCSId:       $Id: host.h,v 1.10 1996/08/20 12:30:44 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -69,13 +69,14 @@
  *    on a connection before opening up a new connection (or refusing
  *    new articles if we get to MAXCXNS).
  * PORTNUM is the port number on the remote host we should talk to.
- * IMMEDOPEN, if non-zero then the initial connections to the remote host
- *    are opened immediately, rather that when the first article is handed
- *    to us.
  * CLOSEPERIOD is the number of seconds after connecting that the
  *     connections should be closed down and reinitialized (due to problems
  *     with old NNTP servers that hold history files open. Value of 0 means
  *     dont close down.
+ * STREAMING is a boolean flag to tell if the Host wants its Connections to
+ *     do streaming or not.
+ * LOWPASSHIGH is the high value for the low-pass filter.
+ * LOWPASSLOW is the low value for the low-pass filter.
  */
 Host newHost (InnListener listener,
               const char *peerName,     
@@ -87,8 +88,9 @@ Host newHost (InnListener listener,
               u_int maxCheck,
               u_short portNum,
               u_int closePeriod,
-              double lowPassHigh,
-              double lowPassLow) ;
+              bool streaming,
+              double lowPassLow,
+              double lowPassHigh) ;
 
 
 /* print some debugging info. */
@@ -180,6 +182,9 @@ bool hostLogConnectionStatsP (void) ;
 /* Set the frequency (in seconds) with which we log statistics */
 void hostSetStatsPeriod (u_int period) ;
 
+/* return whether or not the Connections should attempt to stream. */
+bool hostWantsStreaming (Host host) ;
+
 /* return the maximum number of CHECKs that can be outstanding */
 u_int hostMaxChecks (Host host) ;
 
