@@ -4,7 +4,7 @@
  * Start Date:  Mon, 15 Jan 1996 17:31:58 +1100
  * Project:     INN -- innfeed
  * File:        main.c
- * RCSId:       $Id: main.c,v 1.14 1996/06/05 14:03:43 brister Exp brister $
+ * RCSId:       $Id: main.c,v 1.16 1996/08/20 13:28:09 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -29,7 +29,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: main.c,v 1.14 1996/06/05 14:03:43 brister Exp brister $" ;
+static const char *rcsid = "$Id: main.c,v 1.16 1996/08/20 13:28:09 brister Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -48,6 +48,7 @@ static void use_rcsid (const char *rid) {   /* Never called */
 #include <errno.h>
 #include <fcntl.h>
 #include <assert.h>
+#include <math.h>
 
 #if defined (DO_HAVE_UNISTD)
 #include <unistd.h>
@@ -90,10 +91,14 @@ static bool getHostInfo (FILE *fp,
                          u_int *initialConnections,
                          u_int *maxConnections,
                          u_int *maxChecks,
-                         bool *immediateOpen,
+                         bool *streaming,
+                         double *lowFilter,
+                         double *highFilter,
                          u_short *portNumber) ;
 static bool getOptUInt (u_int *field, char *line, u_int fNum, u_int defVal) ;
 static bool getOptBool (bool *field, char *line, u_int fNum, bool defVal) ;
+static bool getOptDouble (double *field, char *line, u_int fieldNum,
+                          double defVal) ;
 static void sigchld (int sig) ;
 static void sigusr (int sig) ;
 static void usage (int) ;
@@ -105,8 +110,10 @@ u_int defaultResponseTimeout ;
 u_int defaultInitialConnections ;
 u_int defaultMaxConnections ;
 u_int defaultMaxChecks ;
+bool defaultStreaming ;
+double defaultLowFilter ;
+double defaultHighFilter ;
 u_short defaultPortNumber ;
-bool defaultImmediateOpen ;
 bool talkToSelf ;
 
 extern char *versionInfo ;
@@ -127,7 +134,9 @@ int main (int argc, char **argv)
   FILE *fp ;
   char *name, *ipName ;
   u_int artTout, respTout, initCxns, maxCxns, maxChecks ;
-  bool immedOpen, seenV = false ;
+  double lowFilter, highFilter ;
+  bool streaming ;
+  bool seenV = false ;
   u_short portNum ;
   bool dynamicPeers = false ;
   time_t now = theTime() ;
@@ -374,30 +383,33 @@ int main (int argc, char **argv)
   openfds++ ;
   
   while (getHostInfo (fp, &name, &ipName, &artTout, &respTout, &initCxns,
-                      &maxCxns, &maxChecks, &immedOpen, &portNum))
+                      &maxCxns, &maxChecks, &streaming, &lowFilter,
+                      &highFilter,&portNum))
     {
       nHost = newHost (listener,name,ipName,artTout,respTout,initCxns,
                        maxCxns,maxChecks,portNum,CLOSE_PERIOD,
-                       LOW_PASS_FILTER_ON,LOW_PASS_FILTER_OFF) ;
+                       streaming,lowFilter,highFilter) ;
 
       /* this is where we'll die if the locks are still held. */
       if (nHost == 0)
         {
           syslog (LOG_ERR,NO_HOST,name) ;
-          sleep (1) ;
-          exit (1) ;
         }
+      else 
+        {
+          if (initCxns == 0 && talkToSelf)
+            syslog (LOG_NOTICE,BATCH_AND_NO_CXNS,name) ;
 
-      if (initCxns == 0 && talkToSelf)
-        syslog (LOG_NOTICE,BATCH_AND_NO_CXNS,name) ;
-      
-      dprintf (1,"Adding %s %s article (%d) response (%d) initial (%d) max con (%d) max checks (%d) portnumber (%d)\n",
-               name, ipName, artTout, respTout, initCxns, maxCxns,
-               maxChecks, portNum) ;
+          dprintf (1,"Adding %s %s article (%d) response (%d) initial (%d) max con (%d) max checks (%d) portnumber (%d) streaming (%s) lowFilter (%.2f) highFilter (%.2f)\n",
+                   name, ipName, artTout, respTout, initCxns, maxCxns,
+                   maxChecks, portNum, streaming ? "true" : "false",
+                   lowFilter, highFilter) ;
 
-      if ( nHost != NULL && !listenerAddPeer (listener,nHost) )
-        die ("failed to add a new peer\n") ;
+          if ( nHost != NULL && !listenerAddPeer (listener,nHost) )
+            die ("failed to add a new peer\n") ;
+        }
     }
+  
 
   if ( !feof (fp) )
     {
@@ -459,7 +471,7 @@ static void usage (int val)
   /* parse lines of the form used in the config file:
 
      name:fqdn:article-timeout:initial-connections:response-timeout:
-     max-connections:max-q-size:immediate-open:portnum
+     max-connections:max-q-size:streaming:low-filter:high-filter:portnum
 
      XXX i'm not handling continuation lines yet.
      */
@@ -473,15 +485,19 @@ static bool getHostInfo (FILE *fp,
                          u_int *initialConnections,
                          u_int *maxConnections,
                          u_int *maxChecks,
-                         bool *immediateOpen,
+                         bool *streaming,
+                         double *lowFilter,
+                         double *highFilter,
                          u_short *portNumber) 
 {
-  static seenDefault ;
-  char line [256], copyLine [256] ;
+  static bool seenDefault ;
+  char line [1024], copyLine [1024] ;
   char *p, *l ;
   char *field1, *field2 ;
-  u_int field3, field4, field5, field6, field7, field9 ;
+  u_int field3, field4, field5, field6, field7 ;
   bool field8 ;
+  double field9, field10 ;
+  u_int field11 ;
   bool gotSomething = false ;
 
   dprintf (1,"Starting...\n") ;
@@ -491,7 +507,7 @@ static bool getHostInfo (FILE *fp,
       gotSomething = false ;
       dprintf (1,"Doing config line: %s\n",line) ;
       
-      strcpy (copyLine,line) ;
+      strcpy (copyLine,line) ;  /* copyLine is used for syslog only */
       
       for (l = line ; *l != '\0' && isspace (*l) ; l++)
           /* nada */ ;
@@ -557,14 +573,28 @@ static bool getHostInfo (FILE *fp,
       if ( !getOptUInt (&field7,copyLine,7,defaultMaxChecks) )
         return false ;
 
-        /* field 8 the immediate open flag */
-      if ( !getOptBool (&field8,copyLine,8,defaultImmediateOpen) )
+      /* field 8 the streaming flag */
+      if ( !getOptBool (&field8,copyLine,8,defaultStreaming) )
         return false ;
 
-        /* field 9 the port number */
-      if ( !getOptUInt (&field9,copyLine,9,defaultPortNumber) )
+      /* field 9 the low-pass filter low value. */
+      if ( !getOptDouble (&field9,copyLine,9,defaultLowFilter) )
         return false ;
 
+      /* field 10 the low-pass filter high value */
+      if ( !getOptDouble (&field10,copyLine,10,defaultHighFilter) )
+        return false ;
+
+      /* field 11 the port number */
+      if ( !getOptUInt (&field11,copyLine,11,defaultPortNumber) )
+        return false ;
+
+      if (field9 > field10)
+        {
+          syslog (LOG_ERR,LOW_GREATER,field1) ;
+          exit (1) ;
+        }
+      
       if (strcmp (field1,"default") != 0)
         {
           gotSomething = true ;
@@ -578,16 +608,20 @@ static bool getHostInfo (FILE *fp,
       defaultInitialConnections = field5 ;
       defaultMaxConnections = field6 ;
       defaultMaxChecks = field7 ;
-      defaultImmediateOpen = field8 ;
-      defaultPortNumber = field9 ;
+      defaultStreaming = field8 ;
+      defaultLowFilter = field9 ;
+      defaultHighFilter = field10 ;
+      defaultPortNumber = field11 ;
 
-      dprintf (1,"defaults are set %d %d %d %d %d %s %d\n",
+      dprintf (1,"defaults are set %d %d %d %d %d %s %.2f %.2f %d\n",
                defaultArticleTimeout,
                defaultResponseTimeout,
                defaultInitialConnections,
                defaultMaxConnections,
                defaultMaxChecks,
-               defaultImmediateOpen ? "true" : "false",
+               defaultStreaming ? "true" : "false",
+               defaultLowFilter,
+               defaultHighFilter,
                defaultPortNumber
                ) ;
       
@@ -609,8 +643,10 @@ static bool getHostInfo (FILE *fp,
   *initialConnections = field5 ;
   *maxConnections = field6 ;
   *maxChecks = field7 ;
-  *immediateOpen = field8 ;
-  *portNumber = field9 ;
+  *streaming = field8 ;
+  *lowFilter = field9 ;
+  *highFilter = field10 ;
+  *portNumber = field11 ;
 
   return true ;
 }
@@ -618,12 +654,14 @@ static bool getHostInfo (FILE *fp,
 
 
 void getHostDefaults (u_int *articleTout,
-                             u_int *respTout,
-                             u_int *initialCxns,
-                             u_int *maxCxns,
-                             u_int *maxChecks,
-                             bool *immedOpen,
-                             u_short *portNum)
+                      u_int *respTout,
+                      u_int *initialCxns,
+                      u_int *maxCxns,
+                      u_int *maxChecks,
+                      bool *streaming,
+                      double *lowFilter,
+                      double *highFilter,
+                      u_short *portNum)
 {
   ASSERT (defaultMaxConnections > 0) ;
   
@@ -632,18 +670,64 @@ void getHostDefaults (u_int *articleTout,
   ASSERT (initialCxns != NULL) ;
   ASSERT (maxCxns != NULL) ;
   ASSERT (maxChecks != NULL) ;
-  ASSERT (immedOpen != NULL) ;
   ASSERT (portNum != NULL) ;
+  ASSERT (streaming != NULL) ;
+  ASSERT (lowFilter != NULL) ;
+  ASSERT (highFilter != NULL) ;
+  
   
   *articleTout = defaultArticleTimeout ;
   *respTout = defaultResponseTimeout ;
   *initialCxns = defaultInitialConnections ;
   *maxCxns = defaultMaxConnections ;
   *maxChecks = defaultMaxChecks ;
-  *immedOpen = defaultImmediateOpen ;
+  *streaming = defaultStreaming ;
+  *lowFilter = defaultLowFilter ;
+  *highFilter = defaultHighFilter ;
   *portNum = defaultPortNumber ;
 }
 
+
+static bool getOptDouble (double *field, char *line, u_int fieldNum,
+                          double defVal)
+{
+  char *tok, *ptr ;
+
+  if ((tok = mystrtok (NULL,":")) == NULL)
+    *field = defVal ;
+  else if (strlen (tok) > 0)
+    {
+      errno = 0 ;
+
+      /* yeah, I know I could collapse these all into one giant if. */
+      if (((*field = strtod (tok, &ptr)) == 0) && (ptr == tok))
+        {
+          dprintf (1,"Bad field %d in line: %s\n", fieldNum, line) ;
+          return false ;
+        }
+      else if (*ptr != '\0')
+        {
+          dprintf (1,"Bad field %d in line: %s\n", fieldNum, line) ;
+          return false ;
+        }
+      else if ((*field == -(HUGE_VAL) || *field == HUGE_VAL) &&
+               errno == ERANGE)
+        {
+          dprintf (1,"Bad field %d in line: %s\n", fieldNum, line) ;
+          return false ;
+        }
+      else if (*field == 0 && errno == ERANGE)
+        {
+          dprintf (1,"Bad field %d in line: %s\n", fieldNum, line) ;
+          return false ;
+        }
+    }
+  else
+    *field = defVal ;
+
+  return true ;
+}
+
 static bool getOptBool (bool *field, char *line, u_int fieldNum, bool defVal)
 {
   char *tok, *ptr, *p ;
@@ -730,6 +814,8 @@ static void sigchld (int sig)
 #if 0
   wait (&status) ;              /* we don't care */
 #endif
+
+  signal (sig,sigchld) ;
 }
 
 
@@ -740,6 +826,8 @@ static void sigusr (int sig)
     loggingLevel++ ;
   else if (sig == SIGUSR2 && loggingLevel > 0)
     loggingLevel-- ;
+
+  signal (sig,sigusr) ;
 }
 
 
