@@ -4,7 +4,7 @@
  * Start Date:  Wed Nov 29 23:44:47 1995
  * Project:     INN (innfeed)
  * File:        misc.h
- * RCSId:       $Id: misc.h,v 1.9 1996/05/19 22:25:52 brister Exp brister $
+ * RCSId:       $Id: misc.h,v 1.10 1996/08/20 13:40:12 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -147,7 +147,8 @@ bool isOlder (const char *file1, const char *file2) ;
 
   /* lives in main.c */
 void getHostDefaults (u_int *articleTout, u_int *respTout, u_int *initialCxns,
-                      u_int *maxCxns, u_int *maxChecks, bool *immedOpen,
+                      u_int *maxCxns, u_int *maxChecks, bool *streaming,
+                      double *lowFilter, double *highFilter,
                       u_short *portNum) ;
 
 
