@@ -4,7 +4,7 @@
  * Start Date:  Thu, 01 Feb 1996 22:17:51 +1100
  * Project:     INN -- innfeed
  * File:        sysconfig.h
- * RCSId:       $Id: sysconfig.h,v 1.6 1996/06/05 14:05:06 brister Exp brister $
+ * RCSId:       $Id: sysconfig.h,v 1.7 1996/08/20 14:04:33 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -50,7 +50,7 @@
 */
 
 #if defined (__bsdi__)
-#define MAX_IOVEC 1024
+#define MAX_WRITEV_VEC 1024
 #endif
 
 /*
@@ -58,7 +58,7 @@
 */
 
 #if defined (__FreeBSD__)
-#define MAX_IOVEC 1024
+#define MAX_WRITEV_VEC 1024
 #endif
 
 /*
@@ -67,7 +67,7 @@
 */
 
 #if defined (__NetBSD__)
-#define MAX_IOVEC 1024
+#define MAX_WRITEV_VEC 1024
 #endif
 
 
@@ -76,7 +76,10 @@
 */
 
 #if defined (linux)
-#define MAX_IOVEC 1024
+
+/* Note: If you are running version 5.4.3 or better of libc, then 16 is the
+   number to use. Lower than that, and you should use 1. */
+#define MAX_WRITEV_VEC 1
 #endif
 
 
@@ -87,7 +90,7 @@
 
 #if defined (__osf__)
 #define GETSOCKOPT_ARG  char *
-#define MAX_IOVEC  1024
+#define MAX_WRITEV_VEC  1024
 #endif
 
 
@@ -99,7 +102,7 @@
 #if defined (SOLARIS)
 /* #define DO_NEED_STRERROR 1 */  /* this is needed for version < 2.5 */
 #define GETSOCKOPT_ARG  char *
-#define MAX_IOVEC  16
+#define MAX_WRITEV_VEC  16
 #define DO_NEED_STREAM 1
 
 #define wait3(a,b,c) waitpid(-1,a,b)
@@ -111,18 +114,18 @@
 */
 
 #if defined (sun) && ! defined (SOLARIS)
-#define MAX_IOVEC 16          /* That's mighty small... */
+#define MAX_WRITEV_VEC 16
 #define DO_NEED_STRERROR 1
 #endif
 
 
 /*
-** IRIX 5.2
+** IRIX
 **
 */
 
 #if defined (__sgi)
-#define MAX_IOVEC 1024          /* actually bigger */
+#define MAX_WRITEV_VEC 16    /* actually bigger on 5.2, but this on 5.3 and 6.x */
 #endif
 
 
@@ -132,7 +135,7 @@
 */
 #if defined (_nec_ews)
 #define DO_NEED_STRDUP 1
-#define MAX_IOVEC 16
+#define MAX_WRITEV_VEC 16
 #define DO_NEED_STREAM 1
 #endif
 
@@ -169,8 +172,8 @@
    to test for your system. 16 is the smallest number I've come across
    yet. Having a number that's too small won't break anything. Having a
    number that's too big will. */
-#if ! defined (MAX_IOVEC)
-#define MAX_IOVEC 16
+#if ! defined (MAX_WRITEV_VEC)
+#define MAX_WRITEV_VEC 16
 #endif
 
 
