@@ -4,7 +4,7 @@
  * Start Date:  Thu, 01 Feb 1996 18:52:39 +1100
  * Project:     INN -- innfeed
  * File:        uio_maxiov.c
- * RCSId:       $Id: uio_maxiov.c,v 1.3 1996/04/13 02:51:33 brister Exp brister $
+ * RCSId:       $Id: uio_maxiov.c,v 1.4 1996/08/20 14:08:58 brister Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -30,7 +30,7 @@
  */
 
 #if ! defined (lint)
-static const char *rcsid = "$Id: uio_maxiov.c,v 1.3 1996/04/13 02:51:33 brister Exp brister $" ;
+static const char *rcsid = "$Id: uio_maxiov.c,v 1.4 1996/08/20 14:08:58 brister Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -98,12 +98,12 @@ int main(int argc, char ** argv)
             }
           else
             {
-              printf ("UIO_MAXIOV (MAX_IOVEC) looks to be %d\n", size - 1) ;
+              printf ("UIO_MAXIOV (MAX_WRITEV_VEC) looks to be %d\n", size - 1) ;
               exit (0) ;
             }
         }
       else if (size == MAXTRY)
-        printf ("UIO_MAXIOV (MAX_IOVEC) looks to be *at least* %d\n", MAXTRY);
+        printf ("UIO_MAXIOV (MAX_WRITEV_VEC) looks to be *at least* %d\n", MAXTRY);
 
       free (array) ;
     }
